"use client";

import { getFetch } from "@/lib/doFetch";
import { useRequest } from "ahooks";
import { Image, Divider, Button } from "@nextui-org/react";
import dayjs from "dayjs";
import { ArrowLeftOutlined } from "@ant-design/icons";
import EditFolder from "@/components/EditFolder";
import DeleteFolder from "@/components/DeleteFolder";
import AddFolder from "@/components/AddFolder";
import AddCollection from '@/components/AddCollection';
import Cards from "@/components/Cards";
import Collections from "@/components/Collections";
import { useRouter } from "next/navigation";
import { AiFillHome } from "react-icons/ai";


export default function Detail({ folder, params }) {
  //params.slug 路由传参获取
  const router = useRouter();

  const { data, refreshAsync } = useRequest(
    async () => {
      let res = await getFetch({
        url: "/api/folder/" + params.slug,
        params: {},
      });
      return res?.data;
    },
    {
      refreshDeps: [params.slug],
    }
  );

  return (
    <div className="flex w-full">
      <Image
        isBlurred
        className="object-cover w-100 m-12"
        src={data?.poster}
        width={400}
        alt="avatar"
      />
      <div className="ml-20 mt-12 flex-1">
        <div className="space-y-1">
          <h1 className="text-2xl mb-2">{data?.name}</h1>
          <p className="text-small text-default-400 ">
            创建时间:
            {data?.createdAt
              ? dayjs(data.createdAt).format("YYYY-MM-DD hh:mm:ss")
              : "-"}
          </p>
        </div>
        <Divider className="my-4" />
        <div className="flex items-center space-x-4 text-small mt-8">
          <Button
            isIconOnly
            color="primary"
            variant="faded"
            aria-label="Take a add"
            onPress={() => {
              router.back();
            }}
          >
            <ArrowLeftOutlined></ArrowLeftOutlined>
          </Button>
          <Divider orientation="vertical" />
          <Button
            isIconOnly
            color="primary"
            variant="faded"
            aria-label="Take a add"
            onPress={() => {
              router.replace('/');
            }}
          >
            <AiFillHome style={{ fontSize: "18px" }} />
            {/* <Image src='/logo.png' style={{width:24,height:"auto"}}/> */}
          </Button>
          <Divider orientation="vertical" />
          <DeleteFolder data={data} refresh={refreshAsync}></DeleteFolder>
          <Divider orientation="vertical" />
          <EditFolder data={data} refresh={refreshAsync} />
          <Divider orientation="vertical" />
          <AddFolder
            refresh={refreshAsync}
            parentId={params.slug}
            type={"icon"}
          ></AddFolder>
          <Divider orientation="vertical" />
          <AddCollection
            refresh={refreshAsync}
            parentId={params.slug}
            type={"icon"}
          />
        </div>

        <div className="mt-8 flex flex-wrap gap-2">
          <Cards list={data?.folders ?? []}></Cards>
          <Collections list={data?.collections ?? []}></Collections>
                {data?.folders?.length === 0 &&data?.collections?.length ===0 &&  (
        <Image
          alt="empty"
          isZoomed
          className="object-cover"
          src="/empty.png"
          width={240}
        />
      )}
        </div>
      </div>
    </div>
  );
}
